@@ -1116,9 +1116,33 @@ class TestModelSync(unittest.TestCase):
             self.assertEqual(msvc.inactive, True)
 
             # Reactivate it
+            services = {'service01': service}
             await sync_preseem_model(self.model, self.company.uuid, 'test_source', ElementRole.AP, [], services=services)
             await self.checkSourceService(service)
             services = {x.source_id: x for x in await self.model.Service.List(company_uuid=self.company.uuid)}
             msvc = services.get(service.id)
             self.assertIsNotNone(msvc)
             self.assertEqual(msvc.inactive, False)
+        self._await(test())
+
+    def test_service_ip_prefix_format(self):
+        """If the service returns a different IP format, the comparison is done correctly."""
+        async def test():
+            # create a service
+            accounts = {'acct01': Account('acct01', None, AccountStatus.ACCOUNT_STATUS_ACTIVE, 'Account 1', None, None)}
+            packages = {'pkg01': Package('pkg01', 'Package 1', 25000, 5000)}
+            service = Service('service01', account_id='acct01', package_id='pkg01', download_rate=100000, upload_rate=20000, subscriber_identifier='account01', url='https://my.source.url')
+            service.attachment.network_prefixes.append('192.0.2.101')
+            services = {'service01': service}
+            await sync_preseem_model(self.model, self.company.uuid, 'test_source', ElementRole.AP, [], accounts=accounts, packages=packages, services=services)
+            await self.checkSourceService(service)
+
+            # change the prefix that comes back to a "/32" (reflects actual behavior)
+            model_services = await self.model.Service.List(company_uuid=self.company.uuid)
+            msvc = model_services[0]
+            self.model._services[msvc.company_uuid][msvc.uuid].attachment.network_prefixes[0] += '/32'
+
+            # The sync shouldn't change anything in the model.
+            await sync_preseem_model(self.model, self.company.uuid, 'test_source', ElementRole.AP, [], accounts=accounts, packages=packages, services=services)
+            self.assertEqual(self.model._services[msvc.company_uuid][msvc.uuid].attachment.network_prefixes[0], "192.0.2.101/32")
+        self._await(test())
