@@ -183,35 +183,11 @@ class TestNetworkElementUpdate(unittest.TestCase):
         pppoe_client = neu.pppoe_clients.add()
         self.assertEqual(len(neu.pppoe_clients), 1)
 
-        if_name = 'testifname1'
-        self.assertEqual(pppoe_client.if_name, None)
-        pppoe_client.if_name = if_name
-        self.assertEqual(pppoe_client.if_name, if_name)
-        pppoe_client.if_name = None
-        self.assertEqual(pppoe_client.if_name, None)
-
         pppoe_client.errctx = network_element_update.ErrorContext()
-        self.assertEqual(pppoe_client.if_index, None)
-        pppoe_client.if_index = 11
-        self.assertEqual(pppoe_client.if_index, 11)
-        pppoe_client.if_index = -1
-        self.assertEqual(pppoe_client.if_index, 11)
-        pppoe_client.if_index = pow(2, 31) + 1
-        self.assertEqual(pppoe_client.if_index, 11)
-        pppoe_client.if_index = None
-        self.assertEqual(len(pppoe_client.errctx.errors), 2)
-        pppoe_client.errctx = None
 
         pppoe_client.username = "user1"
         self.assertEqual(pppoe_client.username, "user1")
 
-        ip_address = '0b:00:00:01:02:03'
-        self.assertEqual(pppoe_client.ip_address, None)
-        pppoe_client.ip_address = ip_address
-        self.assertEqual(pppoe_client.ip_address, ip_address)
-        pppoe_client.ip_address = None
-        self.assertEqual(pppoe_client.ip_address, None)
-
         mac_address = '0b:00:00:01:02:04'
         self.assertEqual(pppoe_client.mac_address, None)
         pppoe_client.mac_address = mac_address
@@ -221,6 +197,19 @@ class TestNetworkElementUpdate(unittest.TestCase):
 
         del neu.pppoe_clients[0]
         self.assertEqual(len(neu.pppoe_clients), 0)
+        
+        self.assertEqual(list(pppoe_client.network_prefixes), [])
+        pppoe_client.network_prefixes.append('192.0.2.100')
+        self.assertEqual(len(pppoe_client.network_prefixes), 1)
+        self.assertEqual(pppoe_client.network_prefixes[0], '192.0.2.100')
+        pppoe_client.network_prefixes.append('192.0.3.100/29')
+        self.assertEqual(len(pppoe_client.network_prefixes), 2)
+        self.assertEqual(pppoe_client.network_prefixes[1], '192.0.3.100/29')
+        del pppoe_client.network_prefixes[1]
+        self.assertEqual(len(pppoe_client.network_prefixes), 1)
+        del pppoe_client.network_prefixes[0]
+        self.assertEqual(len(pppoe_client.network_prefixes), 0)
+
 
         # Check copy behavior of sub-message assignment
         ne = network_element_update.NetworkElement()
